'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = format;

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DEFAULT_SIGNS = [' ', '⚠', '✖'];
const DEFAULT_COLORS = ['white', 'yellow', 'red'];

function format(report = {}, options = {}) {
	var _options$signs = options.signs;
	const signs = _options$signs === undefined ? DEFAULT_SIGNS : _options$signs;
	var _options$colors = options.colors;
	const colors = _options$colors === undefined ? DEFAULT_COLORS : _options$colors;
	var _options$color = options.color;
	const enabled = _options$color === undefined ? true : _options$color;
	var _report$errors = report.errors;
	const errors = _report$errors === undefined ? [] : _report$errors;
	var _report$warnings = report.warnings;
	const warnings = _report$warnings === undefined ? [] : _report$warnings;


	const problems = [...errors, ...warnings].map(problem => {
		const sign = signs[problem.level] || '';
		const color = colors[problem.level] || 'white';
		const decoration = enabled ? _chalk2.default[color](sign) : sign;
		const name = enabled ? _chalk2.default.grey(`[${problem.name}]`) : `[${problem.name}]`;
		return `${decoration}   ${problem.message} ${name}`;
	});

	const sign = selectSign({ errors, warnings });
	const color = selectColor({ errors, warnings });

	const decoration = enabled ? _chalk2.default[color](sign) : sign;
	const summary = `${decoration}   found ${errors.length} problems, ${warnings.length} warnings`;
	return [...problems, enabled ? _chalk2.default.bold(summary) : summary];
}

function selectSign(report) {
	if (report.errors.length > 0) {
		return '✖';
	}
	return report.warnings.length ? '⚠' : '✔';
}

function selectColor(report) {
	if (report.errors.length > 0) {
		return 'red';
	}
	return report.warnings.length ? 'yellow' : 'green';
}
module.exports = exports['default'];
//# sourceMappingURL=index.js.map